
# Stilus

[![Travis (.org) branch](https://img.shields.io/travis/jw/stilus/master.svg?style=flat-square)](https://travis-ci.org/jw/stilus)
[![Codecov branch](https://img.shields.io/codecov/c/github/jw/stilus/master.svg?style=flat-square)](https://codecov.io/gh/jw/stilus)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/stilus.svg?style=flat-square)](https://pypi.org/project/stilus/#files)
[![PyPI](https://img.shields.io/pypi/v/stilus.svg?style=flat-square)](https://pypi.org/project/stilus/#history)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/stilus.svg?style=flat-square)](https://pypi.org/project/stilus/#description)

A Stylus css compiler in Python.  Very much a work in progress...
